==> mediawiki-1.14.0.tgz: mediawiki/languages/messages/MessagesNv.php <==
<?php
/** Navajo (Diné bizaad)
 *
 * @ingroup Language
 * @file
 *
 * @author לערי ריינהארט
 */

$namespaceNames = array(
	NS_MEDIA            => 'Media',
	NS_SPECIAL          => 'Special',
	NS_MAIN	            => '',
	NS_TALK	            => 'Naaltsoos_baa_yinísht\'į́',
	NS_USER             => 'Choinish\'įįhí',
	NS_USER_TALK        => 'Choinish\'įįhí_baa_yinísht\'į́',
	# NS_PROJECT set by $wgMetaNamespace
	NS_PROJECT_TALK     => '$1_baa_yinísht\'į́',
	NS_FILE             => 'E\'elyaaígíí',
	NS_FILE_TALK        => 'E\'elyaaígíí_baa_yinísht\'į́',
	NS_MEDIAWIKI        => 'MediaWiki',
	NS_MEDIAWIKI_TALK   => 'MediaWiki_baa_yinísht\'į́',
	NS_TEMPLATE         => 'Template',
	NS_TEMPLATE_TALK    => 'Template_talk',
	NS_HELP             => 'Aná\'álwo\'',
	NS_HELP_TALK        => 'Aná\'álwo\'_baa_yinísht\'į́',
	NS_CATEGORY         => 'T\'ááłáhági_át\'éego',
	NS_CATEGORY_TALK    => 'T\'ááłáhági_át\'éego_baa_yinísht\'į́'
);

$datePreferences = false;

$messages = array(
# Dates
'sunday'    => 'Damóogo',
'monday'    => 'Damóo biiskání',
'tuesday'   => 'Damóodóó naakiską́o',
'wednesday' => 'Damóodóó tágí jį́',
'thursday'  => "Damóodóó dį́į́' yiską́o",
'friday'    => "Nda'iiníísh",
'saturday'  => 'Yiską́ damóo',
'january'   => "Yas Niłt'ees",
'february'  => 'Atsá Biyáázh',
'march'     => "Wóózhch'į́į́d",
'april'     => "T'ą́ą́chil",
'may_long'  => "T'ą́ą́tsoh",
'june'      => "Ya'iishjááshchilí",
'july'      => "Ya'iishjáástsoh",
'august'    => "Bini'ant'ą́ą́ts'ózí",
'september' => "Bini'ant'ą́ą́tsoh",
'october'   => 'Ghąąjį',
'november'  => "Níłch'its'ósí",
'december'  => "Níłch'itsoh",
'jan'       => 'Ynts',
'feb'       => 'Atsb',
'mar'       => 'Wozh',
'apr'       => 'Tchi',
'may'       => 'Ttso',
'jun'       => 'Yjsh',
'jul'       => 'Yjts',
'aug'       => 'Btsz',
'sep'       => 'Btsx',
'oct'       => 'Ghąj',
'nov'       => 'Ntss',
'dec'       => 'Ntsx',

'edit' => 'Łahgo áshłééh',

# Skin names
'skinname-monobook' => "NaaltsoosŁáa'ígíí",

);

==> mediawiki-1.15.1.tgz: mediawiki/languages/messages/MessagesNv.php <==
<?php
/** Navajo (Diné bizaad)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author לערי ריינהארט
 */

$namespaceNames = array(
	NS_MEDIA            => 'Media',
	NS_SPECIAL          => 'Special',
	NS_MAIN	            => '',
	NS_TALK	            => 'Naaltsoos_baa_yinísht\'į́',
	NS_USER             => 'Choinish\'įįhí',
	NS_USER_TALK        => 'Choinish\'įįhí_baa_yinísht\'į́',
	# NS_PROJECT set by $wgMetaNamespace
	NS_PROJECT_TALK     => '$1_baa_yinísht\'į́',
	NS_FILE             => 'E\'elyaaígíí',
	NS_FILE_TALK        => 'E\'elyaaígíí_baa_yinísht\'į́',
	NS_MEDIAWIKI        => 'MediaWiki',
	NS_MEDIAWIKI_TALK   => 'MediaWiki_baa_yinísht\'į́',
	NS_TEMPLATE         => 'Template',
	NS_TEMPLATE_TALK    => 'Template_talk',
	NS_HELP             => 'Aná\'álwo\'',
	NS_HELP_TALK        => 'Aná\'álwo\'_baa_yinísht\'į́',
	NS_CATEGORY         => 'T\'ááłáhági_át\'éego',
	NS_CATEGORY_TALK    => 'T\'ááłáhági_át\'éego_baa_yinísht\'į́'
);

$datePreferences = false;

$messages = array(
# Dates
'sunday'    => 'Damóogo',
'monday'    => 'Damóo biiskání',
'tuesday'   => 'Damóodóó naakiską́o',
'wednesday' => 'Damóodóó tágí jį́',
'thursday'  => "Damóodóó dį́į́' yiską́o",
'friday'    => "Nda'iiníísh",
'saturday'  => 'Yiską́ damóo',
'january'   => "Yas Niłt'ees",
'february'  => 'Atsá Biyáázh',
'march'     => "Wóózhch'į́į́d",
'april'     => "T'ą́ą́chil",
'may_long'  => "T'ą́ą́tsoh",
'june'      => "Ya'iishjááshchilí",
'july'      => "Ya'iishjáástsoh",
'august'    => "Bini'ant'ą́ą́ts'ózí",
'september' => "Bini'ant'ą́ą́tsoh",
'october'   => 'Ghąąjį',
'november'  => "Níłch'its'ósí",
'december'  => "Níłch'itsoh",
'jan'       => 'Ynts',
'feb'       => 'Atsb',
'mar'       => 'Wozh',
'apr'       => 'Tchi',
'may'       => 'Ttso',
'jun'       => 'Yjsh',
'jul'       => 'Yjts',
'aug'       => 'Btsz',
'sep'       => 'Btsx',
'oct'       => 'Ghąj',
'nov'       => 'Ntss',
'dec'       => 'Ntsx',

'edit' => 'Łahgo áshłééh',

# Skin names
'skinname-monobook' => "NaaltsoosŁáa'ígíí",

);
